@@ -15,21 +15,10 @@ our @EXPORT         = qw();
 use List::MoreUtils qw(uniq);
 use Text::Unidecode;
 
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 
-# Unicode variants available since http://www.nntp.perl.org/group/perl.perl5.changes/2010/10/msg27957.html
-my $NON_WORD = ($^V < 5.013007)
-    ? q([
-        \p{SpacePerl} |
-        \p{PosixCntrl} |
-        \p{PosixPunct}
-    ]+)
-    : q([
-        \p{XPerlSpace} |
-        \p{XPosixCntrl} |
-        \p{XPosixPunct}
-    ]+);
+my $NON_WORD = qr{ [\W_]+ }x;
 
 sub fingerprint ($) {
     my ($string) = @_;
@@ -40,7 +29,7 @@ sub fingerprint ($) {
         sort(
             uniq(
                 split(
-                    m{${NON_WORD}}ox,
+                    m{ $NON_WORD }ox,
                     lc(unidecode($string))
                 )
             )
@@ -51,9 +40,9 @@ sub fingerprint ($) {
 sub fingerprint_ngram ($;$) {
     my ($string, $n) = (@_, 2);
 
-    $string =~ s{${NON_WORD}}{}gosx;
+    $string =~ s{ $NON_WORD }{}gosx;
 
-    return join q() =>
+    return join '' =>
         sort(
             uniq(
                 lc(unidecode($string)) =~ m{
@@ -80,7 +69,7 @@ Text::Fingerprint - perform simple text clustering by key collision
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -135,7 +124,7 @@ change all characters to their lowercase representation
 
 =item *
 
-split the string into punctuation, whitespace and control characters-separated tokens
+split the string into punctuation, whitespace and control characters-separated tokens (using C</[\W_]/> regexp)
 
 =item *
 
@@ -150,16 +139,13 @@ join the tokens back together
 =head2 fingerprint_ngram($string, $n)
 
 The L<n-gram|http://en.wikipedia.org/wiki/N-gram> fingerprint method is similar to the C<fingerprint> method described above but instead of using whitespace separated tokens, it uses I<n-grams>, where the C<$n> (or the size in chars of the token) can be specified by the user (default: 2).
+Algorithm steps:
 
 =over 4
 
 =item *
 
-change all characters to their lowercase representation
-
-=item *
-
-remove all punctuation, whitespace, and control characters
+remove all punctuation, whitespace, and control characters (using C</[\W_]/> regexp)
 
 =item *
 
@@ -167,6 +153,10 @@ normalize extended western characters to their ASCII representation
 
 =item *
 
+change all characters to their lowercase representation
+
+=item *
+
 obtain all the string n-grams
 
 =item *
@@ -179,6 +169,11 @@ join the sorted n-grams back together
 
 =back
 
+=head1 CAVEAT
+
+Fingerprint functions I<are not exactly the same> as those found in Google Refine!
+They were slightly changed to take advantage of the superb Perl handling of Unicode characters.
+
 =head1 SEE ALSO
 
 =over 4
